@@ -12,6 +12,7 @@ import tempfile
 import time
 
 import hglib
+import rs_parsepatch
 import structlog
 from libmozdata.phabricator import PhabricatorPatch
 
@@ -150,13 +151,28 @@ class Repository(object):
         try:
             logger.info("Updating repo to revision {}".format(hg_base))
             self.repo.update(rev=hg_base, clean=True)
+
+            # See if the repo is clean
+            repo_status = self.repo.status(
+                modified=True, added=True, removed=True, deleted=True
+            )
+            if len(repo_status) != 0:
+                logger.warn(
+                    "Repo is dirty! Let's clean it first.",
+                    revision=hg_base,
+                    repo=self.name,
+                    repo_status=repo_status,
+                )
+                # Clean the repo - This is a workaround for Bug 1720302
+                self.repo.update(rev="null", clean=True)
+                # Redo the update to the correct revision
+                self.repo.update(rev=hg_base, clean=True)
+
         except hglib.error.CommandError:
             raise Exception("Failed to update to revision {}".format(hg_base))
 
-        # Get current revision using full information tuple from hglib
-        revision = self.repo.identify(id=True).strip()
-        revision = self.repo.log(revision, limit=1)[0]
-        logger.info("Updated repo", revision=revision.node, repo=self.name)
+        # In this case revision is `hg_base`
+        logger.info("Updated repo", revision=hg_base, repo=self.name)
 
         def get_author(commit):
             """Helper to build a mercurial author from Phabricator data"""
@@ -273,11 +289,12 @@ class MercurialWorker(object):
     Mercurial worker maintaining several local clones
     """
 
-    def __init__(self, queue_name, queue_phabricator, repositories):
+    def __init__(self, queue_name, queue_phabricator, repositories, skippable_files=[]):
         assert all(map(lambda r: isinstance(r, Repository), repositories.values()))
         self.queue_name = queue_name
         self.queue_phabricator = queue_phabricator
         self.repositories = repositories
+        self.skippable_files = skippable_files
 
     def register(self, bus):
         self.bus = bus
@@ -305,6 +322,23 @@ class MercurialWorker(object):
                     "Unsupported repository", repo=build.repo_phid, build=build
                 )
 
+    def is_commit_skippable(self, build):
+        def get_files_touched_in_diff(rawdiff):
+            patched = []
+            for parsed_diff in rs_parsepatch.get_diffs(rawdiff):
+                # filename is sometimes of format 'test.txt  Tue Feb 05 17:23:40 2019 +0100'
+                # fix after https://github.com/mozilla/rust-parsepatch/issues/61
+                if "filename" in parsed_diff:
+                    filename = parsed_diff["filename"].split(" ")[0]
+                    patched.append(filename)
+            return patched
+
+        return any(
+            patched_file in self.skippable_files
+            for rev in build.stack
+            for patched_file in get_files_touched_in_diff(rev.patch)
+        )
+
     def handle_build(self, repository, build):
         """
         Try to load and apply a diff on local clone
@@ -321,6 +355,18 @@ class MercurialWorker(object):
             # First apply patches on local repo
             repository.apply_build(build)
 
+            # Check Eligibility: some commits don't need to be pushed to try.
+            if self.is_commit_skippable(build):
+                logger.info("This patch series is ineligible for automated try push")
+                return (
+                    "fail:ineligible",
+                    build,
+                    {
+                        "message": "Modified files match skippable internal configuration files",
+                        "duration": time.time() - start,
+                    },
+                )
+
             # Configure the try task
             repository.add_try_commit(build)
 
